/**
* @license Apache-2.0
*
* Copyright (c) 2022 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MAIN //

/**
* Revives a JSON-serialized regular expression.
*
* @param {string} key - key
* @param {*} value - value
* @returns {(*|RegExp)} regular expression
*
* @example
* var parseJSON = require( '@stdlib/utils/parse-json' );
*
* var str = '{"type":"RegExp","pattern":"ab+c","flags":""}';
*
* var re = parseJSON( str, reviver );
* // returns <RegExp>
*/
function reviver( key, value ) {
	if ( value && value.type === 'RegExp' && value.pattern ) {
		return new RegExp( value.pattern, value.flags );
	}
	return value;
}


// EXPORTS //

module.exports = reviver;
